Func class

Writing Minecrafts functions annotations becomes really easy. Just annotate a Widget variable that should be inside of your function with @Func():

Constructors

Func({String? name, String? pack, String? path = '/', bool? execute, bool? create})
Writing Minecrafts functions annotations becomes really easy. Just annotate a Widget variable that should be inside of your function with @Func():
const

Properties

create → bool?
final
execute → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
pack → String?
final
path → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited