Pck class

The @Pck() annotation works similar to @Func. You annotate a File List variable and it generates a Widget for this Pack.

Constructors

Pck({String? name, String? main, String? load})
The @Pck() annotation works similar to @Func. You annotate a File List variable and it generates a Widget for this Pack.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
load → String?
final
main → String?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited