Prj class

This can automatically generate a main function with all necessary pieces to actually generate all packs and files.

Constructors

Prj({String? name, int? version, String? target, String? description, bool genMain = true})
This can automatically generate a main function with all necessary pieces to actually generate all packs and files.
const

Properties

description → String?
final
genMain → bool
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → String?
final
version → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited