ArmorStand class

Inheritance

Constructors

ArmorStand(Location location, {TextComponent? name, bool? nameVisible, Map<String, dynamic>? nbt, List<String>? tags, bool? invisible, bool? invulnerable, bool? marker, bool? hasArms, bool? basePlate, Item? mainHand, Item? offHand, Item? head, Item? chest, Item? legs, Item? boots, bool? gravity, bool? glowing, int? fire, bool? small, List<Summon>? passengers, Rotation? rotation, Pose? pose})
An ArmorStand can be created with the Summon Widget, but there is also a specific Widget with special properties for an ArmorStand.
ArmorStand.staticMarker(Location location, {TextComponent? name, bool? nameVisible, Map<String, dynamic>? nbt, bool? invisible = true, bool invulnerable = true, bool gravity = false, Item? mainHand, Item? offHand, Item? head, Item? chest, Item? legs, Item? boots, bool? glowing, int? fire, bool? small, List<Summon>? passengers, Rotation? rotation, List<String>? tags, Pose? pose})
Often times you need a static ArmorStand that just acts as a marker for a location, there is ArmorStand.staticMarker that sets properties automatically.

Properties

age ↔ int?
getter/setter pairinherited
basePlate ↔ bool?
getter/setter pair
boots ↔ Item?
getter/setter pair
called ↔ bool
Contains the Information, if this RestAction is already called (and can't be called again)
getter/setter pairinherited
chest ↔ Item?
getter/setter pair
effects ↔ List<Effect>?
getter/setter pairinherited
fire ↔ int?
getter/setter pairinherited
glowing ↔ bool?
getter/setter pairinherited
gravity ↔ bool?
getter/setter pairinherited
hasArms ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
invisible ↔ bool?
getter/setter pair
invulnerable ↔ bool?
getter/setter pairinherited
legs ↔ Item?
getter/setter pair
location ↔ Location
getter/setter pairinherited
mainHand ↔ Item?
getter/setter pair
marker ↔ bool?
getter/setter pair
name ↔ TextComponent?
getter/setter pairinherited
nameVisible ↔ bool?
getter/setter pairinherited
nbt ↔ Map<String, dynamic>?
getter/setter pairinherited
noAI ↔ bool?
getter/setter pairinherited
offHand ↔ Item?
getter/setter pair
passengers ↔ List<Summon>?
getter/setter pairinherited
persistent ↔ bool?
getter/setter pairinherited
pose → Pose?
final
rotation ↔ Rotation?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
silent ↔ bool?
getter/setter pairinherited
small ↔ bool?
getter/setter pairinherited
tags ↔ List<String>?
getter/setter pairinherited
type ↔ EntityType
getter/setter pairinherited
writable ↔ List<Widget>?
The writable list the RestAction writes it's contents on
getter/setter pairinherited

Methods

generate(Context context) → Widget
inherited
getMap() → Map
inherited
getNbt([bool useId = true]) → Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queue([List<Widget>? writable]) → void
Execute this method to add this to the WidgetList (can use default list or as parameter given list) This method can only be executed once, if it is executed multiple times you will get an Error. You can read out if it is already executed in the boolean Called Example for a queue method:
inherited
select({String selector = 'e', bool useType = true, bool useTags = true, int? limit}) → Entity
If you have an existing Summon object(or Armorstand) you can invoke .select to give you a corresponding Entity selector.
inherited
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited