Block class

Constructors

Block(String _id)
Usage:
const
Block.nbt(dynamic block, {Map<String, dynamic>? states, String? tag, Map<String, dynamic>? nbt, String strNbt = ''})

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
no setter
nbt → Map<String, dynamic>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
states → Map<String, dynamic>?
final
strNbt → String
final
tag → String?
final

Methods

getBlockState() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited