Byte class

Datatype Byte

Inheritance

Constructors

Byte(int num, {ErrorGenerator? error_generator})
Used to insert a byte into nbt data
Byte.Boolean(bool b, {ErrorGenerator? error_generator})
Used to insert a boolean into nbt data

Properties

boolValue → bool?
The boolean value (if the byte is no boolean then null)
no setter
hashCode → int
The hash code for this object.
no setterinherited
isBool → bool
is the Byte a boolean
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → int
the byte value (number from -128 to 127)
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(dynamic v) → void
Set byte to number or boolean
toSimple() → int
returns a simple, json compatible representation of the content
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited