CommandBuilder class

Inheritance

Constructors

CommandBuilder(String command)

Properties

command → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, String? command}) → CommandBuilder
entity(Entity? entity, {List<String>? also, String? prefix, String? suffix}) → CommandBuilder
generate(Context context) → Widget
override
location(Location? location, {List<String>? also, String? prefix, String? suffix}) → CommandBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
number(num? val, {List<String>? also, String? prefix, String? suffix}) → CommandBuilder
string(String? str, {List<String>? also, String? prefix, String? suffix}) → CommandBuilder
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited
when(bool condition, {String? then, List<String>? also, String? prefix, String? suffix, String? otherwise}) → CommandBuilder

Operators

operator ==(Object other) → bool
The equality operator.
inherited