Damage class

Inheritance

Constructors

Damage(Entity target, {required double amount, String? damageType, Location? location, Entity? by, Entity? cause})
Wrapper for the damage command which simulates the situation of causing damage to the entity.
Damage.at(Location? location, {required Entity target, required double amount, String? damageType})
Damage.by(Entity? by, {required Entity target, required double amount, String? damageType, Entity? cause})

Properties

amount → double
final
by → Entity?
final
cause → Entity?
final
damageType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
location → Location?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → Entity
final

Methods

generate(Context context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited