DataModify class

There are five sub operations again: set, merge, prepend, append and insert.

Constructors

DataModify.append(dynamic value, {String fromPath = ''})
DataModify.appendString(dynamic value, {String fromPath = '', int? start, int? end})
DataModify.insert(dynamic value, {String fromPath = '', int? index = 0})
DataModify.insertString(dynamic value, {String fromPath = '', int? start, int? end, int? index = 0})
DataModify.merge(dynamic value, {String fromPath = ''})
DataModify.mergeString(dynamic value, {String fromPath = '', int? start, int? end})
DataModify.prepend(dynamic value, {String fromPath = ''})
DataModify.prependString(dynamic value, {String fromPath = '', int? start, int? end})
DataModify.set(dynamic value, {String fromPath = ''})
DataModify.setString(dynamic value, {String fromPath = '', int? start, int? end})

Properties

end ↔ int?
getter/setter pair
fromPath ↔ String
getter/setter pair
fromSource ↔ String
getter/setter pair
fromType ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ int?
getter/setter pair
type ↔ String
getter/setter pair
value ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited