Display class

Spawns an diplay entity used to display and animate text, items and blocks in the world, having the following common fields.

Inheritance

Constructors

Display.block(Location location, Block block, {Map<String, dynamic>? nbt, int? age, List<String>? tags, Time? interpolationDuration, Time? startInterpolation, double? shadowRadius, double? shadowStrength, double? viewRange, BillboardType? billboardType, Transformation? transformation})
Spawns an diplay entity used to display and animate blocks in the world.
Display.item(Location location, Item item, {Map<String, dynamic>? nbt, int? age, List<String>? tags, Time? interpolationDuration, Time? startInterpolation, double? shadowRadius, double? shadowStrength, double? viewRange, BillboardType? billboardType, Transformation? transformation, ItemDisplay? itemDisplay})
Spawns an diplay entity used to display and animate items in the world.
Display.text(Location location, TextComponent? text, {Map<String, dynamic>? nbt, int? age, List<String>? tags, Time? interpolationDuration, Time? startInterpolation, double? shadowRadius, double? shadowStrength, double? viewRange, BillboardType? billboardType, TextAlignment? alignment, int? textOpacity, bool? seeThrough, int? lineWidth, Transformation? transformation})
Spawns an diplay entity used to display and animate text in the world.

Properties

age ↔ int?
getter/setter pairinherited
alignment → TextAlignment?
final
billboardType → BillboardType?
final
block → Block?
final
called ↔ bool
Contains the Information, if this RestAction is already called (and can't be called again)
getter/setter pairinherited
effects ↔ List<Effect>?
getter/setter pairinherited
fire ↔ int?
getter/setter pairinherited
glowing ↔ bool?
getter/setter pairinherited
gravity ↔ bool?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
interpolationDuration → Time?
final
invulnerable ↔ bool?
getter/setter pairinherited
item → Item?
final
itemDisplay → ItemDisplay?
final
lineWidth → int?
final
location ↔ Location
getter/setter pairinherited
name ↔ TextComponent?
getter/setter pairinherited
nameVisible ↔ bool?
getter/setter pairinherited
nbt ↔ Map<String, dynamic>?
getter/setter pairinherited
noAI ↔ bool?
getter/setter pairinherited
passengers ↔ List<Summon>?
getter/setter pairinherited
persistent ↔ bool?
getter/setter pairinherited
rotation ↔ Rotation?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seeThrough → bool?
final
shadowRadius → double?
final
shadowStrength → double?
final
silent ↔ bool?
getter/setter pairinherited
small ↔ bool?
getter/setter pairinherited
startInterpolation → Time?
final
tags ↔ List<String>?
getter/setter pairinherited
text → TextComponent?
final
textOpacity → int?
final
transformation → Transformation?
final
type ↔ EntityType
getter/setter pairinherited
viewRange → double?
final
writable ↔ List<Widget>?
The writable list the RestAction writes it's contents on
getter/setter pairinherited

Methods

generate(Context context) → Widget
inherited
getMap() → Map
inherited
getNbt([bool useId = true]) → Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queue([List<Widget>? writable]) → void
Execute this method to add this to the WidgetList (can use default list or as parameter given list) This method can only be executed once, if it is executed multiple times you will get an Error. You can read out if it is already executed in the boolean Called Example for a queue method:
inherited
select({String selector = 'e', bool useType = true, bool useTags = true, int? limit}) → Entity
If you have an existing Summon object(or Armorstand) you can invoke .select to give you a corresponding Entity selector.
inherited
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

animate(Entity entity, Time duration, {Time start = const Time(0), double? shadowStrength, Transformation? transformation, double? shadowRadius, int? textOpacity}) → Data
Given the entity to animate, duration, start time, and animatable fields, this constructs a data command.
set(Entity entity, {Time? duration, Time? start, double? shadowStrength, Transformation? transformation, double? shadowRadius, int? textOpacity}) → Data
Given the entity and display fields, this constructs a data command setting the values.