File class

Inheritance

Constructors

File(String path, {Widget? child, bool execute = false, String? pack, bool create = true, bool inheritFolder = true, Comment? header})
The file class simply generates a new mcfunction file with content and a path.
File.execute(String path, {Widget? child, String? pack, bool create = true, Comment? header, bool inheritFolder = true, Object? arguments})
the execute subconstructor adds an execution statement forwarding to the new file into the original
File.executeStrait(String path, {required dynamic child(List<Widget>), String? pack, bool create = true, Comment? header, Object? arguments})
factory
File.recursive()
File.strait(String path, {required dynamic child(List<Widget>), bool execute = false, String? pack, bool create = true, Comment? header})
File.strait generates the child strait through a method you give using a StraitWidget. You need a StraitWidget on around every strait content
factory

Properties

arguments ↔ Object?
getter/setter pair
child ↔ Widget?
getter/setter pair
create ↔ bool
getter/setter pair
execute ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
getter/setter pair
inheritFolder ↔ bool
getter/setter pair
isRecursive ↔ bool?
getter/setter pair
pack ↔ String?
getter/setter pair
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fullPath([Path? p]) → Path
generate(Context context) → Command
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run({bool create = false, Object? arguments}) → File
toMap() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited