Folder class

The Folder Widget gives you a way to place all following files inside a specific folder path.

Inheritance

Constructors

Folder(String path, {required Widget child})
The Folder Widget gives you a way to place all following files inside a specific folder path.

Properties

child ↔ Widget
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
path ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(Context context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited