GsonDecoder class

The Gson Decoder class recreates the content from a gson string

Constructors

GsonDecoder()
gson decoder (if you want to use it use the instance from gson.decoder)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(dynamic gson) → dynamic
Insert gson to decode
decodeArray(dynamic src) → List
Decode an array
decodeMap(dynamic src) → Map<String, dynamic>
Decode a map
decodeNumber(dynamic src) → NumberValue
Decode a number
decodeString(dynamic src) → String
Decode a String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited