GsonEncoder class

Constructors

GsonEncoder()
Encodes gson

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

beautyEncode(dynamic obj, {int indent = 2, bool quoteMapKeys = false, dynamic jsonBooleans = false}) → List<String>
encode beautified gson
encode(dynamic obj, {bool beautify = false, int indent = 2, bool quoteMapKeys = false, dynamic jsonBooleans = false}) → String
Insert object to encode it as GSON
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited