GsonParsable class

A parsable object for the GsonDecoder to use

Inheritance
  • Object
  • ErrorGenerator
  • GsonParsable
Implementers

Constructors

GsonParsable(String _parsable, {int position = 0})

Properties

ended → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
parsable → String
no setter
position → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

actual() → String
Get actual
error(String message, {int from = 0, int to = 0}) → Exception
generate a error at the position of the parsable
override
goBack(int number) → void
Go Steps back
has(int space) → bool
test if has amount of symbols left
hasNext() → bool
test if has next symbol
next() → String
Get actual and go one forward
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peek(int number) → String
peek forward
reformatError(Exception e, [StackTrace? stack]) → Exception
reformat error
skip() → void
Skip one
toString({int from = 0, int to = 0, bool err = false}) → String
String representation of parsable (marks actual position)
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited