If class

Inheritance

Constructors

If(dynamic condition, {required List<Widget> then, List<Widget>? orElse, String targetFilePath = 'objd', String? targetFileName, bool encapsulate = true, Entity? assignTag, String useTag = 'objd_isTrue'})
The if widget accepts a Condition and runs the children if the condition is true.
If.not(dynamic condition, {required List<Widget> then, List<Widget>? orElse, String targetFilePath = 'objd', String? targetFileName, bool encapsulate = true, Entity? assignTag, String useTag = 'objd_isTrue'})
You can negate the Condition with If.not:

Properties

assignTag ↔ Entity?
getter/setter pair
called ↔ bool
Contains the Information, if this RestAction is already called (and can't be called again)
getter/setter pairinherited
conds ↔ List<List>
getter/setter pair
elseWidget ↔ If?
getter/setter pair
encapsulate ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invert ↔ bool
getter/setter pair
orElse ↔ List<Widget>?
getter/setter pair
predicate ↔ Predicate?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetFileName ↔ String?
getter/setter pair
targetFilePath ↔ String
getter/setter pair
then ↔ List<Widget>
getter/setter pair
useTag → String
final
writable ↔ List<Widget>?
The writable list the RestAction writes it's contents on
getter/setter pairinherited

Methods

generate(Context context) → Widget
override
getCondition(dynamic condition) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queue([List<Widget>? writable]) → void
Execute this method to add this to the WidgetList (can use default list or as parameter given list) This method can only be executed once, if it is executed multiple times you will get an Error. You can read out if it is already executed in the boolean Called Example for a queue method:
inherited
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited