JsonFile class

Inheritance

Constructors

JsonFile(String path, Map<String, dynamic>? contents, {bool useGson = false, bool inheritFolder = false})
As a way to easily generate .json files, you can use the JsonFile wrapper. Just provide a map and a path
JsonFile.list(String path, List? contentsList, {bool useGson = false, bool inheritFolder = false})
As a way to easily generate .json files, you can use the JsonFile wrapper. Just provide a list and a path

Properties

contents → Map<String, dynamic>?
final
contentsList → List?
final
hashCode → int
The hash code for this object.
no setterinherited
inheritFolder → bool
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useGson → bool
final

Methods

generate(Context context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited