Marker class

Added in Minecraft 1.17 this entity only exists serversides and thus has no performance constraints for the client.

Inheritance

Constructors

Marker(Location location, {Map<String, dynamic>? nbt, Map<String, dynamic>? data, List<String>? tags})
Added in Minecraft 1.17 this entity only exists serversides and thus has no performance constraints for the client. Best used to save locations and even custom nbt data with the data field.

Properties

age ↔ int?
getter/setter pairinherited
called ↔ bool
Contains the Information, if this RestAction is already called (and can't be called again)
getter/setter pairinherited
data ↔ Map<String, dynamic>?
getter/setter pair
effects ↔ List<Effect>?
getter/setter pairinherited
fire ↔ int?
getter/setter pairinherited
glowing ↔ bool?
getter/setter pairinherited
gravity ↔ bool?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
invulnerable ↔ bool?
getter/setter pairinherited
location ↔ Location
getter/setter pairinherited
name ↔ TextComponent?
getter/setter pairinherited
nameVisible ↔ bool?
getter/setter pairinherited
nbt ↔ Map<String, dynamic>?
getter/setter pairinherited
noAI ↔ bool?
getter/setter pairinherited
passengers ↔ List<Summon>?
getter/setter pairinherited
persistent ↔ bool?
getter/setter pairinherited
rotation ↔ Rotation?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
silent ↔ bool?
getter/setter pairinherited
small ↔ bool?
getter/setter pairinherited
tags ↔ List<String>?
getter/setter pairinherited
type ↔ EntityType
getter/setter pairinherited
writable ↔ List<Widget>?
The writable list the RestAction writes it's contents on
getter/setter pairinherited

Methods

generate(Context context) → Widget
inherited
getMap() → Map
inherited
getNbt([bool useId = true]) → Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queue([List<Widget>? writable]) → void
Execute this method to add this to the WidgetList (can use default list or as parameter given list) This method can only be executed once, if it is executed multiple times you will get an Error. You can read out if it is already executed in the boolean Called Example for a queue method:
inherited
select({String selector = 'e', bool useType = true, bool useTags = true, int? limit}) → Entity
If you have an existing Summon object(or Armorstand) you can invoke .select to give you a corresponding Entity selector.
inherited
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited