Pack class

Inheritance

Constructors

Pack({required String name, File? main, File? load, List<File>? files, List<Module>? modules})
A pack is logically the next step after a Project. This defines a sub-pack with an name again that will be our namespace afterwards.

Properties

files ↔ List<File>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
load ↔ File?
getter/setter pair
main ↔ File?
getter/setter pair
modules ↔ List<Module>?
getter/setter pair
name ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate(Context context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited