Parsable class

Inheritance

Constructors

Parsable(String parsable)
ObjD's own type of a Parsable

Properties

ended → bool
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
parsable → String
no setterinherited
position → int
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

actual() → String
Get actual
inherited
error(String message, {int from = 0, int to = 0}) → Exception
generate a error at the position of the parsable
inherited
goBack(int number) → void
Go Steps back
inherited
has(int space) → bool
test if has amount of symbols left
inherited
hasNext() → bool
test if has next symbol
inherited
next() → String
Get actual and go one forward
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peek(int number) → String
peek forward
inherited
reformatError(Exception e, [StackTrace? stack]) → Exception
reformat error
inherited
skip() → void
Skip one
inherited
toString({int from = 0, int to = 0, bool err = false}) → String
String representation of parsable (marks actual position)
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited