Path class

Constructors

Path(List<String> segments, {String? filename, String? filetype})
const
Path.from(String path, {String? type})
factory

Properties

filename → String?
final
filetype → String?
final
hashCode → int
The hash code for this object.
no setteroverride
isEmpty → bool
no setter
isNotEmpty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments → List<String>
final

Methods

append(String path, {String? type}) → Path
copyWith({List<String>? segments, String? filename, String? filetype}) → Path
join(Path p) → Path
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({bool withExtension = true}) → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override