PlayerJoin class

Allows you to specify what should happen if a player joins. This can be triggered every time or just once with PlayerJoin.inital

Inheritance

Constructors

PlayerJoin({required Widget? then, Entity? target, String score = 'objd_join'})
This will create a score that counts leave_game stats and checks if the player has the score thus detecting if a player joins.
PlayerJoin.initial({Widget then(Score)?, Entity? target, String score = 'objd_join'})
This gives every player a unique id on join and enables you to do something the first time around with the score holding the players id.
PlayerJoin.rejoin({required Widget? then, Entity? target, String score = 'objd_join'})
This will create a score that counts leave_game stats and thus detects if a player rejoins.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → String
final
subcommand → String
final
target → Entity?
final
then → Widget?
final

Methods

generate(Context context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited