Pose class

An armorstand Pose describing rotations of all body parts

Constructors

Pose({List<double>? head, List<double>? body, List<double>? lleg, List<double>? rleg, List<double>? larm, List<double>? rarm})
An armorstand Pose describing rotations of all body parts
Pose.fromMap(Map<String, dynamic> map)
factory

Properties

body → List<double>?
final
hashCode → int
The hash code for this object.
no setterinherited
final
larm → List<double>?
final
lleg → List<double>?
final
rarm → List<double>?
final
rleg → List<double>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<double>? head, List<double>? body, List<double>? lleg, List<double>? rleg, List<double>? larm, List<double>? rarm}) → Pose
getMap() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setArms(List<double> l, [List<double>? r]) → Pose
setBody(List<double> values) → Pose
setHead(List<double> values) → Pose
setLegs(List<double> l, [List<double>? r]) → Pose
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited