Project class

Constructors

Project({required String name, required Widget generate, double version = 20.4, String target = './', int? packFormat, List<int>? supportedFormats, String description = 'This is a datapack generated with objd by Stevertus'})
The project is a special Widget which is just defined once.

Properties

description → String
final
generate ↔ Widget
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
packFormat → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedFormats → List<int>?
final
target ↔ String
getter/setter pair
version → double
final

Methods

getPackFormat() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited