Range class

Constructors

Range(num? from, num? to)
The Range class defines a range of values(e.g 3..10 in vanilla)
Range.exact(num? exact)
Use Range.exact to get the exact Range(e.g 4)
Range.from(num? from)
Use Range.to to define greater than or equal
Range.to(num? to)
Use Range.to to define less than or equal

Properties

exact ↔ num?
getter/setter pair
from ↔ num?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to ↔ num?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited