RestActionBuilder class

Constructors

RestActionBuilder(List<Widget> writable)
Made for creating RestActions, useful for APIs if you need to create multiple RestActions

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writable ↔ List<Widget>
getter/setter pair

Methods

create(Widget rest) → RestActionAble
createAll(List<Widget> rest) → RestActionAble
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited