Ride class

Inheritance

Constructors

Ride(Entity entity, Entity vehicle)
Makes one entity ride another.
Ride.dismount(Entity entity)
With Ride.dismount you can dismount an entity

Properties

entity → Entity
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vehicle → Entity?
final

Methods

generate(Context context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited