Rotation class

Constructors

Rotation(String _rotation)
The Rotation Widget is very similar to Location but takes in just two directions for an entities rotation:
Rotation.east({double dx = 0, double y = 0})
factory
Rotation.glob({double x = 0, double y = 0})
Rotation.here()
Rotation.north({double dx = 0, double y = 0})
factory
Rotation.rel({double x = 0, double y = 0})
Rotation.south({double dx = 0, double y = 0})
factory
Rotation.west({double dx = 0, double y = 0})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ double
getter/setter pair
y ↔ double
getter/setter pair

Methods

getDirection() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

checkEast → Range
no setter
checkNorth → Range
no setter
checkSouth → Range
no setter
checkWest → Range
no setter