ServerVersionCheck class

checks the server version (e.g. 1.14) - increments, such as 1.14.1, aren't and can't be detected

Inheritance

Constructors

ServerVersionCheck({int? minVersion, List<Widget>? versionTooLow, Score? serverVersion, Widget then(Score)?})
Checks the used Minecraft Version and can give feedback on it(e.g. Errors).

Properties

hashCode → int
The hash code for this object.
no setterinherited
minVersion → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverVersion → Score?
final
then → Widget Function(Score)?
final
versionTooLow → List<Widget>?
final

Methods

generate(Context context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited