Summon class

Inheritance
Implementers

Constructors

Summon(EntityType type, {TextComponent? name, bool? nameVisible, Map<String, dynamic>? nbt, Location location = const Location.here(), bool? invulnerable, bool? persistent, bool? noAI, bool? silent, bool? gravity, bool? glowing, List<Summon>? passengers, List<Effect>? effects, List<String>? tags, int? fire, bool? small, int? age, Rotation? rotation})
The summon class creates a new entity at a given location.

Properties

age ↔ int?
getter/setter pair
called ↔ bool
Contains the Information, if this RestAction is already called (and can't be called again)
getter/setter pairinherited
effects ↔ List<Effect>?
getter/setter pair
fire ↔ int?
getter/setter pair
glowing ↔ bool?
getter/setter pair
gravity ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invulnerable ↔ bool?
getter/setter pair
location ↔ Location
getter/setter pair
name ↔ TextComponent?
getter/setter pair
nameVisible ↔ bool?
getter/setter pair
nbt ↔ Map<String, dynamic>?
getter/setter pair
noAI ↔ bool?
getter/setter pair
passengers ↔ List<Summon>?
getter/setter pair
persistent ↔ bool?
getter/setter pair
rotation ↔ Rotation?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
silent ↔ bool?
getter/setter pair
small ↔ bool?
getter/setter pair
tags ↔ List<String>?
getter/setter pair
type ↔ EntityType
getter/setter pair
writable ↔ List<Widget>?
The writable list the RestAction writes it's contents on
getter/setter pairinherited

Methods

generate(Context context) → Widget
override
getMap() → Map
getNbt([bool useId = true]) → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queue([List<Widget>? writable]) → void
Execute this method to add this to the WidgetList (can use default list or as parameter given list) This method can only be executed once, if it is executed multiple times you will get an Error. You can read out if it is already executed in the boolean Called Example for a queue method:
inherited
select({String selector = 'e', bool useType = true, bool useTags = true, int? limit}) → Entity
If you have an existing Summon object(or Armorstand) you can invoke .select to give you a corresponding Entity selector.
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited