TextClickEvent class

Fires on left click, Part of TextComponent.

Constructors

TextClickEvent({required String action, required String value})
Fires on left click, Part of TextComponent.
TextClickEvent.change_page(int to)
changes book page
TextClickEvent.open_url(String url)
Opens the specified web url
TextClickEvent.run_command(Command command)
runs given command
TextClickEvent.suggest(String text)
copies command in chat

Properties

action → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, String>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited