VersionCheck class

Checks whether the player updated or downdated your datapack.

Inheritance

Constructors

VersionCheck(int currentVersion, {String score = 'objd_data', List<Widget>? onDowndate, List<Widget>? onUpdate, Widget then(Score)?})
Checks whether the player updated or downdated your datapack.

Properties

currentVersion ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onDowndate ↔ List<Widget>?
getter/setter pair
onUpdate ↔ List<Widget>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ String
getter/setter pair
then ↔ Widget Function(Score)?
getter/setter pair

Methods

generate(Context context) → Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → dynamic
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited