Location class

Inheritance

Constructors

Location({Tag? predicate, String? biome, Block? block, Map<String, dynamic>? blockState, dynamic dimension, String? feature, Block? fluid, dynamic light, dynamic x, dynamic y, dynamic z, Location? offset})

Properties

biome → String?
final
block → Block?
final
blockState → Map<String, dynamic>?
final
dimension → dynamic
final
feature → String?
final
fluid → Block?
final
hashCode → int
The hash code for this object.
no setterinherited
light → dynamic
final
offset → Location?
final
predicate → Tag?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → dynamic
final
y → dynamic
final
z → dynamic
final

Methods

getJson() → Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited