Properties class

Inheritance

Constructors

Properties({Entity entity = const Entity.This(), EntityType? type, Map<String, dynamic>? nbt, bool? is_baby, bool? is_on_fire, bool? is_sneaking, bool? is_sprinting, bool? is_swimming, Tag? predicate, Range? level, Gamemode? gamemode, List<Stat>? stats, Map<String, bool>? recipes, Map<String, dynamic>? advancements, String? team})

Properties

advancements → Map<String, dynamic>?
final
entity → Entity
final
gamemode → Gamemode?
final
hashCode → int
The hash code for this object.
no setterinherited
is_baby → bool?
final
is_on_fire → bool?
final
is_sneaking → bool?
final
is_sprinting → bool?
final
is_swimming → bool?
final
level → Range?
final
nbt → Map<String, dynamic>?
final
predicate → Tag?
final
recipes → Map<String, bool>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stats → List<Stat>?
final
team → String?
final
type → EntityType?
final

Methods

getJson() → Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited