RandomChance class

Inheritance

Constructors

RandomChance(double chance)
RandomChance.withLooting(double chance, double? looting_multiplier)

Properties

chance → double
final
hashCode → int
The hash code for this object.
no setterinherited
looting_multiplier → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getJson() → Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited