Scores class

Inheritance

Constructors

Scores(Map<String, dynamic> scores, [Entity entity = const Entity.This()])

Properties

entity → Entity
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scores → Map<String, dynamic>
final

Methods

getJson() → Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited