Tool class

Inheritance

Constructors

Tool({Tag? predicate, Range? count, Range? durability, Item? item, String? potion, String? tag, Map<String, dynamic>? nbt, List<EnchantmentData>? storedEnchantments})

Properties

count → Range?
final
durability → Range?
final
hashCode → int
The hash code for this object.
no setterinherited
item → Item?
final
nbt → Map<String, dynamic>?
final
potion → String?
final
predicate → Tag?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storedEnchantments → List<EnchantmentData>?
final
tag → String?
final

Methods

getJson() → Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited